
% WHAT IF? INPUT LAYER

% FIGURE 6B

% !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
% A row of exclamation marks indicates where values may need to be set, for
% example, the shape of the sampled distribution, sample size (1 field, 3 
% fields), or the terminal to gr cell ratio
% !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

% GENERATE MOSSY FIBRE RATES RECEIVED AS INPUT TO A RANK (A SAGITTAL ROW OF 
% 100 FIELDS)
% Randomly generates values that represent mossy fibre rates received as 
% input to a rank. The number of rates is equal to the number of mossy
% fibres which innervate a rank. The estimate of that number depends on the
% mossy fibre terminal to granule cell divergence ratio. The estimates are
% derived outside the program, in the mf code paper

% !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
M = 3645; % assumes a ratio of 1:50
% M = 9112; % assumes a ratio of 1:20
% M = 4554; % assumes a ratio of 1:40
% M = 3036; % assumes a ratio of 1:60

% The physiological range of mf firing rates in the behaving animal is 
% 50-300 Hz. A mean of 175 Hz is therefore mid-range.

% !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
% SELECT A DISTIBUTION

% % FLAT DISTRIBUTION
% % Randomly generates an array (row vector) of M integers in the range 
% % 50-300, with a 'flat' distribution (i.e. all values are equally likely)
% DIST = randi([100 250],1,M);
% muDIST = mean(DIST);
% sdDIST = std(DIST);

% % NORMAL DISTRIBUTION WITH SPECIFIED MEAN AND SD
% % ONE PEAK
m = 250;
% sd = 6.25;
sd = 12.5;
% sd = 25;
% sd = 37.5;
% sd = 50;
DIST = sd.*randn(1,M) + m; % array of M integers randomly drawn from a 
% normal distribution with mean m and standard deviation sd
muDIST = mean(DIST);
sdDIST = std(DIST);
% % THREE PEAKS
% sd = 12.5;
% x = (M/10).*randi(4); xx = (M/10).*randi(4); xxx = M - (x + xx);
% a = randi(100)+50;b = randi(100)+125;c = randi(100)+200;
% aa = sd.*randn(1,round(x))+a;
% bb = sd.*randn(1,round(xx))+b;
% cc = sd.*randn(1,round(xxx))+c;
% DIST = [aa bb cc];
% muDIST = mean(DIST);
% % FIVE PEAKS
% sd = 12.5;
% a = randi(50)+50;b = randi(50)+100;c = randi(50)+150;d = randi(50)+200;e = randi(50)+250;
% aa = sd.*randn(1,M/5)+a;
% bb = sd.*randn(1,M/5)+b;
% cc = sd.*randn(1,M/5)+c;
% dd = sd.*randn(1,M/5)+d;
% ee = sd.*randn(1,M/5)+e;
% DIST = [aa bb cc dd ee];
% muDIST = mean(DIST);

% % UNEVEN AND DISCONTINUOUS DISTRIBUTION
% Hz = 50;
% DIST = [];
% for jj = 1:20
%     int = randi(20); DIST = [DIST, ones(1,round((int/20)*(M/10))) + Hz];
%     Hz = Hz + 12.5;
% end
% muDIST = mean(DIST);
% sdDIST = std(DIST);

% ** LOOP 1 **

% PREALLOCATE STORAGE SPACE
j = 100;
% Arrays
mfs_allflds = zeros(1,j); % Preallocates storage space for the array mfs_allflds
rates_means = zeros(1,j); 
sample_SDs = zeros(1,j);
copies_means = zeros(1,j); 
copies_SDs = zeros(1,j);
% Cell arrays
rates_allflds = cell(1,j); % Preallocates storage space for a 1 x j cell array
copies_allflds = cell(1,j);

% THE PROGRAM MUST REFLECT ANATOMICAL PARAMETERS THAT COULD ADD TO THE
% EFFECT OF CHANCE ON THE OUTCOME OF SAMPLING (I.E. LOCAL BIOLOGICAL
% MESSINESS)

% IN THIS SECTION/LOOP:
% (1) DERIVE THE (VARIABLE) NUMBER OF MFS THAT INNERVATE A FIELD. 
% (2) REPEAT FOR 100 FIELDS, STORED AS A 1 X 100 ARRAY. 
% (3) DERIVE THE NUMBER OF COPIES OF EACH SIGNAL RECEIVED BY A FIELD, 
% STORED AS A 1 X N ARRAY, WHERE N = THE NO. OF MFS WHICH INNERVATE THAT
% FIELD
% (4) DERIVE MF RATES RECEIVED BY EACH FIELD, RANDOMLY SAMPLED FROM DIST, 
% STORED AS A 1 x 100 CELL ARRAY. EACH CELL CONTAINS A COLUMN VECTOR OF 
% LENGTH N
% (5) THE SAME AS (4) BUT WITH COPIES ADDED, STORED AS A CELL ARRAY

i = 1;

while i <= j

    % STEP 1 - generates the ratio of cluster sizes in a simulated field

    % Cluster size ratio means: the ratio of mossy fibres (that contribute
    % at least 1 terminal to a field) that end in a cluster of 4 
    % terminals, 5, 6 and so on up to 12. the ratio is randomly generated. 
    % It is assumed each cluster size occurs with equal probability in the 
    % wider population.

    clust4 = []; clust5 = []; clust6 = []; clust7 = []; clust8 = []; 
    clust9 = []; clust10 = []; clust11 = []; clust12 = [];

    % !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    % The expected number of mossy fibres that innervate a field, derived
    % in the paper 
    expmf = 182.25; % assumes a mossy fibre terminal to granule cell divergence ratio of 1:50
%     expmf = 546.75; % ditto, but three fields
%     expmf = 455.6; % assumes a mossy fibre terminal to granule cell divergence ratio of 1:20
%     expmf = 227.7; % assumes a mossy fibre terminal to granule cell divergence ratio of 1:40
%     expmf = 151.8; % assumes a mossy fibre terminal to granule cell divergence ratio of 1:60

    count = 1;

    while count <= expmf % expmf is the expected number of mfs afferent to 
        % a field, an estimate derived in the mf code paper. Provides a  
        % starting point to generate field data. 
        num = randi([4 12],1,1);
        if num == 4
            clust4 = [clust4 1];
            tot4 = sum(clust4); % the number of 4-terminal clusters
        elseif num == 5
            clust5 = [clust5 1];
            tot5 = sum(clust5); % the number of 5-terminal clusters
        elseif num == 6
            clust6 = [clust6 1];
            tot6 = sum(clust6); % etc
        elseif num == 7
            clust7 = [clust7 1];
            tot7 = sum(clust7); 
        elseif num == 8
            clust8 = [clust8 1];
            tot8 = sum(clust8); 
        elseif num == 9
            clust9 = [clust9 1];
            tot9 = sum(clust9);
        elseif num == 10
            clust10 = [clust10 1];
            tot10 = sum(clust10); 
        elseif num == 11
            clust11 = [clust11 1];
            tot11 = sum(clust11); 
        else
            clust12 = [clust12 1];
            tot12 = sum(clust12);
        end

        count = count + 1;
    end

    % tot4:tot5:tot6...tot12 is the randomly generated ratio of cluster 
    % sizes
    ratios_sizes = [tot4 tot5 tot6 tot7 tot8 tot9 tot10 tot11 tot12];
    
    % STEP 2 - derives the ratio of terminals in the simulated field 
    % contributed by each cluster size

    % The ratio of cluster sizes is weighted to reflect the greater chance
    % that large clusters ontribute more terminals to a field. The expected
    % ratio of the number of terminals contributed by each cluster size is
    % derived in the main text.  

    exp_ratios_terminals = [22 25 27 28 28 28 28 28 28]; % the expected 
    % ratio of terminals contributed to a field by each cluster size
    % (derived in the mf code paper)
    ratios_terminals = ratios_sizes.*exp_ratios_terminals; % the randomly 
    % generated ratio of terminals per cluster size in the simulated field

    % STEP 3 - derives the number of terminals contributed to the simulated 
    % field by each cluster size 

    % Ratios are converted to fractions. The number of terminals 
    % contributed by each cluster size is the fraction contributed by that
    % size multiplied by the total number of terminals per field (derived
    % in the main text - depends on the terminal to granule cell divergence
    % ratio)

    fractions = ratios_terminals./sum(ratios_terminals); % the fraction of 
    % terminals contributed by each cluster size - what fraction is
    % contributed by mossy fibres ending in 4 terminals, 5 terminals, 6 and 
    % so on
    % !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    terminals = 700; % the total number of terminals per field 
%     terminals = 2100; % three fields
%     terminals = 1750; % one field, terminal to gr cell divergence of 1:20
    sum_each_size = round(fractions.*terminals); % the total number of 
    % terminals contributed by each cluster size

    % STEP 4 - derives the number of mossy fibres that terminate as each 
    % cluster size, which contribute at least one terminal to the simulated
    % field, and from that the number that innervate the field

    % For cluster size m, say, there are associated probabilities that all
    % terminals are inside field limits, m - 1 terminals are inside, m - 2
    % and so on down to 1. The function 'split' randomly generates the 
    % result of straddling field limits, reflecting that smaller clusters 
    % are more likely to have all terminals inside.
    
    % 'mfsn' is the number of mossy fibres which terminate in a cluster of 
    % size n (which have at least one terminal inside the simulated field). 
    % 'arrayn' is a row vector of values in the range 1 to n. Each value
    % corresponds to a mossy fibre, and represents the number of terminals
    % of that cell which are inside the field. Accordingly, mfsn is
    % equal to numel(arrayn).
    
    [mfs4,array4] = split(sum_each_size(1),4);
    [mfs5,array5] = split(sum_each_size(2),5);
    [mfs6,array6] = split(sum_each_size(3),6);
    [mfs7,array7] = split(sum_each_size(4),7);
    [mfs8,array8] = split(sum_each_size(5),8);
    [mfs9,array9] = split(sum_each_size(6),9);
    [mfs10,array10] = split(sum_each_size(7),10);
    [mfs11,array11] = split(sum_each_size(8),11);
    [mfs12,array12] = split(sum_each_size(9),12);

    % STEP 5 - derives the no. of mossy fibres with one terminal inside the
    % simulated field, two, three and so on.

    % Generates the outputs of section 1. these are:
    % (i) sample size i.e. the number of mfs that innervate a simulated field
    % (ii) the number of them that contribute 1 terminal to the field, 2
    % terminals, 3 and so on up to 12

    allmfs = [mfs4 mfs5 mfs6 mfs7 mfs8 mfs9 mfs10 mfs11 mfs12];
    % *********************************************************************
    mfs_1fld = sum(allmfs); % TOTAL MFS AFFERENT TO THE SIMULATED FIELD - 
    % THIS PROVIDES SAMPLE SIZE WHEN MF RATES ARE SAMPLED
    % *********************************************************************
    
    allarrays = [array4 array5 array6 array7 array8 array9 array10 array11 array12];
    terms_1fld = sum(allarrays); % A check - total number of terminals in  
    % the simulated field. Should equal 'terminals'
    
    % *********************************************************************
    mfs_allflds(i) = mfs_1fld; % BUILDS INTO AN ARRAY. VALUES REPRESENT THE 
    % NUMBER OF MFS AFFERENT TO EACH FIELD (IN A ROW OF 100 FIELDS)
    % *********************************************************************
    
    av_mfs_1fld = mean(mfs_allflds); % A check - av_mfs_1fld is mean sample
    % size - this should be somewhere around expmf, the expected no. of mfs 
    % afferent to a field
    
    % A field receives multiple copies of most signals because most mossy
    % fibres contribute more than one terminal. Therefore, copies are added to
    % a sample in the simulation. The number of copies of each signal depends  
    % on relevant probabilities (of each cluster size, of straddling, and of 
    % the result of straddling), and is randomly generated. This has the form 
    % of an array of factors with a number of elements equal to each sample 
    % size. 

    t1 = sum(allarrays == 1); unos = ones(1,t1); % the number of mossy 
    % that contribute one terminal to the simulated field and an array of 
    % ones of that length
    t2 = sum(allarrays == 2); twos = 2.*ones(1,t2); % the number of mossy 
    % fibres that contribute two terminals to the simulated field and an
    % array of twos of that length
    t3 = sum(allarrays == 3); threes = 3.*ones(1,t3); % and so on
    t4 = sum(allarrays == 4); fours = 4.*ones(1,t4);
    t5 = sum(allarrays == 5); fives = 5.*ones(1,t5);
    t6 = sum(allarrays == 6); sixes = 6.*ones(1,t6);
    t7 = sum(allarrays == 7); sevens = 7.*ones(1,t7);
    t8 = sum(allarrays == 8); eights = 8.*ones(1,t8);
    t9 = sum(allarrays == 9); nines = 9.*ones(1,t9);
    t10 = sum(allarrays == 10); tens = 10.*ones(1,t10);
    t11 = sum(allarrays == 11); elevens = 11.*ones(1,t11);
    t12 = sum(allarrays == 12); twelves = 12.*ones(1,t12);

    % *********************************************************************
    copies = [unos twos threes fours fives sixes sevens eights nines tens...
        elevens twelves]; % AN ARRAY OF ONES, TWOS, THREES AND SO ON WHICH
    % REPRESENTS THE NUMBER OF COPIES OF EACH MF SIGNAL RECEIVED BY A
    % FIELD. NOTE: the maximum number of copies of a signal is 7 (because
    % that's the maximum number that fit is a field). t8-t12 have the
    % function of mopping up leftovers returned by 'split', if any.
    % *********************************************************************
    check = numel(copies); % should equal mfs_1fld
    
    % SAMPLE DIST AND ADD COPIES
    rates_1fld = datasample(DIST,mfs_1fld,'Replace',false)'; % A column of 
    % values reoresenting mf rates received by a field
    copies_1fld = repelem(rates_1fld,copies); % A longer column of values 
    % because it contains copies
    
    % *********************************************************************
    rates_allflds{i} = rates_1fld; % BUILDS INTO A 1 X j CELL ARRAY. EACH   
    % CELL CONTAINS A COLUMN OF VALUES, A RANDOM SAMPLE OF DIST, EQUAL TO THE 
    % NUMBER OF MFS AFFERENT TO THAT FIELD, REPRESENTING MF RATES RECEIVED 
    % AS INPUT
    copies_allflds{i} = copies_1fld; % DITTO BUT WITH COPIES ADDED. NOTE: 
    % VALUES STILL REPRESENT MF RATES, BUT THESE INCLUDE COPIES TO REFLECT
    % THE FACT THAT A FIELD RECEIVES COPIES OF MOST SIGNALS
    % *********************************************************************
    
% % % %     if (i > 1) && (i < 5)
% % % %         allcells = zeros(4,8750);
% % % %         for k = 1:8750
% % % %             allcells(:,k) = datasample(copies_1fld,4)'; % NOTE: allcells 
% % % %             % is a sample of copies_added, not sample i.e. gr cells are 
% % % %             % sampling mossy fibre terminals, not mossy fibre rates
% % % %         end
% % % %         if i == 2
% % % %             resample_fld2 = allcells;
% % % %         elseif i == 3
% % % %             resample_fld3 = allcells;
% % % %         else
% % % %             resample_fld4 = allcells;
% % % %         end
% % % %     end
            
    rates_means(i) = mean(rates_1fld);
    copies_means(i) = mean(copies_1fld); 
    copies_SDs(i) = std(copies_1fld);

    i = i + 1

end

% ** LOOP 2 **

% THIS SECTION/LOOP SIMULATES CONVERSION OF MF RATES INTO A MEASURE OF 
% G-CELL SOMATIC DEOPLARISATION, ASSUMED TO BE A (PROBABLY LINEAR) PROXY 
% FOR G-CELL RATES, IN A ROW OF 100 FIELDS

% PREALLOCATE STORAGE SPACE
Gsomata_allflds = zeros(10,j);

for i = 1:j
    
    % SAMPLING BY G-CELLS OF MF SIGNALS RECEIVED BY FIELD i
    Gdend_1fld = zeros(4,50); % a 4 x 50 matrix
    for kk = 1:50
        Gdend_1fld(:,kk) = datasample(copies_allflds{i},4)'; % populates
        % the matrix. Represents random sampling by G-cell basal dendrites
        % of mf signals, sample size 4. There are 50 samples because there
        % are 10 G-cells in a field, each with (av) 5 basal dendrites
    end
    Gdendmeans_1fld = mean(Gdend_1fld); % a 1 x 50 array (the mean of each 
    % column in Gdend_1fld)
    
    % DIVIDE Gdendmeans_1fld INTO GROUPS OF 5 (INPUT VIA 5 BASAL DENDRITES 
    % TO A G-CELL)
% % %     Gcells_1fld = zeros(5,10); 
% % %     for k = 1:10
% % %         Gcells_1fld(:,k) = datasample(Gdendmeans_1fld,5,'Replace',false)'; 
% % %     end
    Gcells_1fld = reshape(Gdendmeans_1fld,5,10); % The same result as randomly  
    % sampling Gdendmeans 30 times without replacement, sample size 5, 
    % storing each sample as a column of a new matrix. It achieves an
    % equivalent of removing sampled values from the initial population,
    % so they can't be picked twice. 5 values per column represents 5
    % basal dendrites per Golgi cell. There are 10 columns because there 
    % are 10 Golgi cells per field
    Gsomata_1fld = mean(Gcells_1fld); % a 1 x 10 array, the mean of each 
    % column in Gcells_1fld. Represents somatic integration of dendritic 
    % signals
    Gsomata_allflds(:,i) = Gsomata_1fld'; % builds into a 10 x j matrix. 
    % Each column represents a field, and each value a G-cell, 10 per
    % field.
        
end

% THIS SECTION/FUNCTION CONVERTS G-CELL SOMA DATA (FOR 100 FIELDS, 10 
% G-CELLS PER FIELD) INTO G-CELL RATES RECEIVED AS CONVERGENT INPUT TO EACH
% GLOMERULUS (ALSO 100 FIELDS, 700 GLOMERULI PER FIELD) RANDOMLY SAMPLING 
% THE G-CELL POPULATION OF 3 FIELDS (IN A ROW, WITH CONVERGENT INPUT TO THE
% MIDDLE FIELD)

GLOM_allflds = sample_threeflds(Gsomata_allflds); % The function turns the 
% simulated data generated in loop 2 into a 700 x 100 matrix of values.
% Each column represents a field. Each value represents a glomerulus (700
% per field). More specifically, it represents GABA concentration, with 
% which it has a proportional or else some other predictable relationship. 
% It is a way of putting a number on inhibitory strength. The purpose of 
% that is i) to see if values are approximately aligned across a field
% (and indeed a whole rank), as predicted, and ii) to use it in the
% simulation of mf to gr cell recoding. 

% ** LOOP 3 **
% THE NEXT STEP IS TO USE THE GLOMERULUS DATA TO GENERATE A 1 X 100 CELL  
% ARRAY, EACH CELL CONTAINING A 4 X 8750 MATRIX, TO REPRESENT RANDOM 
% SAMPLING BY GR CELLS OF GLOMERULI

GABA_allflds = cell(1,j); % preallocate
for i = 1:j
    GABA_1fld = zeros(4,8750); % preallocate
    for k = 1:8750
        sample = datasample(GLOM_allflds(:,i),4)'; % a random sample of 
        % glomeruli in a field, sample size 4 (because gr cells have 4
        % dendrites)
        GABA_1fld(:,k) = sample; % builds a 4 x 8750 matrix. Each column 
        % represents a granule cell (8750 per field) and each value in a
        % column represents glomerular inhibition of each of its 4
        % dendrites
    end
    GABA_allflds{i} = GABA_1fld; % builds into a 1 x j cell array, each 
    % cell contains a 4 x 8750 matrix, as described
end

% ** LOOP 4 **

% SIMULATES SAMPLING BY GRANULE CELLS OF MF RATES

grcells_allflds = cell(1,j); % preallocate

for i = 1:j

    % SAMPLING BY GR CELLS OF MF SIGNALS RECEIVED BY FIELD i
    grcells_1fld = zeros(4,8750); % a 4 x 8750 matrix
    for k = 1:8750
        grcells_1fld(:,k) = datasample(copies_allflds{i},4)'; % populates 
        % the matrix. Represents random sampling by gr cells of mf signals,
        % sample size 4
    end
    grcells_allflds{i} = grcells_1fld; % builds into a 1 x j cell array. 
    % Each cell contains a 4 x 8750 matrix. Values represent mf rates 
    % received as input to each gr cell in each of 100 fields
    grcellmeans_1fld = mean(grcells_1fld); % a 1 x 8750 array (the mean of  
    % each column in grcells_1fld, aka the sample means, representing the 
    % mean of mf rates received as input to each gr cell in a single field)
    grcellmeans_allflds{i} = grcellmeans_1fld; % builds into a 1 x j cell 
    % array. Each cell contains a 1 x 8750 array. Values represent the mean
    % of mf rates received by gr cells in each field, for all fields.
end

% ** LOOP 5 **

% COMPARES VALUES AT CORRESPONDING INDEX POSITIONS OF THE CELL ARRAYS
% GABA_allflds AND grcells_allflds. FOR EACH INDEX PAIR, IF THE FIRST VALUE
% (INHIBITORY STRENGTH) IS HIGHER THAN THE SECOND (EXCITATORY STRENGTH), A 
% ZERO IS INSERTED AT THAT INDEX POSITION OF grcells_allflds. THE OUTPUT OF 
% THIS PROCESS WILL BE USED TO IDENTIFY WHICH GR CELLS FIRE, AND WHAT MF 
% RATES THEY RECEIVE. (THE VALUE REPRESENTING INHIBITORY STRENGTH IS 
% ULTIMATELY DERIVED FROM ALL MF RATES RECEIVED AS INPUT TO THAT FIELD AND
% THE TWO FLANKING FIELDS, AND THE VALUE REPRESENTING EXCITATORY STRENGTH 
% IS THE FIRING RATE OF A SINGLE MF) 

addnoughts = cell(1,j); % preallocate
SDGLOM_allflds = std(GLOM_allflds); % a 1 x 100 array, the SD of GLOM for 
% each field
C = 14;
i = 1;
while i <= j
    a = grcells_allflds{i}; % in each iteration, a is assigned cell i of 
    % grcells_allflds, a 4 x 8750 matrix
    b = GABA_allflds{i}; % same idea
    for k = 1:8750
        c = a(:,k); % in each iteration, c is assigned column k of a
        d = b(:,k); % same idea
        for idx = 1:4
            if c(idx) < (d(idx)+C) % if the condition* is met...
                a(idx,k) = 0; % ...the value of the matrix a at index    
                % position row idx column k is replaced with zero
            end
        end
    end
    addnoughts{i} = a; % a, a 4 x 8750 matrix, is assigned to cell i of the 
    % new cell array addnoughts. Each column represents a granule cell. 0s
    % represent mf signals that do not count towards the gr cell input
    % threshold **
    i = i + 1;
end

% *i.e., in the event that excitation received as input to that glomerulus
% (a single mf signal) is weaker than inhibition (GABA spillover driven by
% convergent input from G-cells)

% **i.e., excitation is weaker than inhibition of that dendrite; or to put
% that another perhaps better way - since 'weaker' suggests a common scale 
% - inhibition prevails over excitation

% ** LOOP 6 **

% THIS SECTION COUNTS THE NUMBER OF 0s A GRANULE CELL RECEIVES. IF IT 
% RECEIVES MORE THAN ONE, IT IS SILENT. THE MAIN OUTPUTS OF THE LOOP ARE i)
% THE NUMBER OF GR CELLS THAT FIRE IN EACH FIELD, AND ii) THE MEAN OF MF
% FIRING RATES THAT ACTIVE CELLS EACH RECEIVE

activecellmeans_allflds = cell(1,j); % preallocate
grcellfldmeans = zeros(1,j); % preallocate
numactive_allflds = zeros(1,j); % preallocate
percent_allflds = zeros(1,j); % preallocate

i = 1;
while i <= j
    add0s = addnoughts{i}; % assigns the (4 x 8750) matrix in cell i to 
    % add0s
    
    idx = add0s==0;
    countnoughts = sum(idx,1); % counts the 0s in each column
    
    grcellmeans_1fld = grcellmeans_allflds{i}; % assigns the (1 x 100) 
    % array in cell i to grcellmeans_1fld
    
    activecellmeans = zeros(1,8750); % preallocate
    for ii = 1:8750
        if countnoughts(ii) >= 2 % if there are more than two 0s in a column...
            activecellmeans(ii) = 0; % ...it is represented as a zero
        else % Otherwise...
            activecellmeans(ii) = grcellmeans_1fld(ii); % ...it is 
            % represented by the mean of mf rates received by that cell
        end
    end
    
    activecellmeans(activecellmeans==0) = [];
    activecellmeans_allflds{i} = activecellmeans; % builds into a 1 X j cell 
    % array of the mean firing rate received by each active gr cell, all
    % fields. Each cell contains a array. Arrays vary in length, reflecting
    % the varible number of gr cells that fire in each field
    
    numactive_1fld = numel(activecellmeans);
    numactive_allflds(i) = numactive_1fld; % builds into an array of the 
    % number of granule cells active in each field

    meanofsamplemeans = mean(activecellmeans); % the mean of the means of 
    % input rates received by each granule cell which fires, in field i
    grcellfldmeans(i) = meanofsamplemeans; % builds into a 1 x j array of the   
    % mean of the sample means for active cells in each field
    SDofsamplemeans = std(activecellmeans); % the SD of the means of input 
    % rates received by each granule cell which fires, in field i
    SDarray(i) = SDofsamplemeans; % builds into a 1 x j array of the SD of the  
    % sample means for active cells in each field

    percent_1fld = numactive_1fld./8750;
    percent_allflds(i) = percent_1fld; % builds into an array of the 
    % percentage of granule cells active in each field
    
    i = i + 1;
end
MINpc = min(percent_allflds);
MAXpc = max(percent_allflds);
MEANpc = mean(percent_allflds);
SDpc = std(percent_allflds);
muFLDS = mean(copies_means);

% FIGURE PANELS

% CHOOSE PANELS!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

opengl software
figure;

subplot(2,6,1)
histogram(DIST,'BinWidth',5,'facecolor',[.81 .7 .55],'facealpha',.3) % [.5 .6 1]
xlabel('Hz');ylabel('');title('mf rates');xlim([50 300]);xticks([100 200 300]);%ylim([0 100]);
set(gca,'FontSize',10)

subplot(2,6,2)
histogram(activecellmeans_allflds{2},'BinWidth',5,'facecolor',[.4 .4 .6],'facealpha',.9)
%histogram(grcellmeans_allflds{2},'BinWidth',5,'facecolor',[.8 1 1],'facealpha',.4)
xlabel('Hz');ylabel('');title('fld 2');xlim([50 300]);xticks([100 200 300]);%ylim([0 10]);
set(gca,'FontSize',10)

subplot(2,6,[3 4 5])
x = 1:j;
A = repelem(muDIST,100); % meanarray, remember, is the mean of the sample means for 

plot(x,A,'color',[.44 .31 .25],'LineWidth',1.1); 
xlabel('fields'); ylabel('Hz'); title('all fields'); xlim([1 100]); ylim([50 300]);
set(gca,'FontSize',10)

hold on

fldavs = grcellfldmeans; % 1 x j array, the mean of the sample means, for active 
% cells, for each of j flds
plot(x,fldavs,'color',[0 0 .4],'LineWidth',1.3); 

% % mupc
% % muDIST
% % mufldavs = mean(fldavs)
% % SDfldavs = std(fldavs)
% % rangefldavs = max(fldavs)-min(fldavs)
